@@ -18,4 +18,7 @@
 from psiz.agents.base import Agent
 from psiz.agents.rank_agent import RankAgent
 
-__all__ = ['Agent', 'RankAgent']
+__all__ = [
+    'Agent',
+    'RankAgent'
+]
