@@ -66,7 +66,7 @@ class Catalog():
         self.n_stimuli = len(stimulus_id)
         stimulus_id = self._check_id(stimulus_id)
         # self.common_path = os.path.commonpath(stimulus_filepath)
-        # TODO modify check, move away from numpy array.
+        # TODO(roads): modify check, move away from numpy array.
         stimulus_filepath = self._check_filepath(stimulus_filepath)
 
         if class_id is None:
@@ -179,7 +179,7 @@ class Catalog():
             max_label_length = len(max(self.class_label.values(), key=len))
 
             n_class = len(self.class_label)
-            class_map_class_id = np.empty(n_class, dtype=np.int)
+            class_map_class_id = np.empty(n_class, dtype=int)
             class_map_label = np.empty(n_class, dtype="S{0}".format(
                 max_label_length
             ))
