@@ -16,7 +16,8 @@
 """Module for loading internally pre-defined datasets.
 
 Functions:
-    load_dataset: Load observations for the requested dataset.
+    load_dataset: Download observations and catalog for the
+        requested dataset.
 
 Notes:
     The dataset will only be downloaded from the server if it does not
@@ -33,6 +34,7 @@ import shutil
 import sys
 import tarfile
 import time
+import warnings
 import zipfile
 
 import numpy as np
@@ -48,32 +50,40 @@ import psiz.trials
 def load_dataset(
         dataset_name, cache_subdir='datasets', cache_dir=None,
         verbose=0):
-    """Load observations and catalog for the requested hosted dataset.
+    """Download observations and catalog for the requested hosted dataset.
 
     Args:
         dataset_name: The name of the hosted dataset.
+        cache_dir (optional): The cache directory for PsiZ.
         cache_subdir (optional): The subdirectory where downloaded
             datasets are cached.
-        cache_dir (optional): The cache directory for PsiZ.
         verbose (optional): Controls the verbosity of printed dataset summary.
 
     Returns:
-        obs: An RankObservations object.
         catalog: A catalog object containing information regarding the
             stimuli used to collect observations.
+        obs: An Observations object.
 
     """
-    # Load from download cache.
-    if cache_dir is None:
-        cache_dir = Path.home() / Path('.psiz')
-    else:
-        cache_dir = Path(cache_dir)
-    dataset_path = cache_dir / Path(cache_subdir, dataset_name)
-    if not dataset_path.exists():
-        dataset_path.mkdir(parents=True)
-
-    obs = _fetch_obs(dataset_name, cache_dir, cache_subdir)
-    catalog = _fetch_catalog(dataset_name, cache_dir, cache_subdir)
+    warnings.warn(
+        (
+            'This function is deprecated and will be removed. Users '
+            'should instead use the '
+            'functionality of their preferred framework such as '
+            '`tf.data.Dataset` to save and load datasets. If you need '
+            'to load a previously hosted dataset, please see the '
+            'separate package `psiz-datasets`; '
+            'version_announced=0.8.0; version_scheduled=0.9.0'
+        ),
+        DeprecationWarning,
+        stacklevel=2
+    )
+    obs = _fetch_obs(
+        dataset_name, cache_subdir=cache_subdir, cache_dir=cache_dir
+    )
+    catalog = _fetch_catalog(
+        dataset_name, cache_subdir=cache_subdir, cache_dir=cache_dir
+    )
 
     if verbose > 0:
         print("Dataset Summary")
@@ -83,14 +93,15 @@ def load_dataset(
     return (obs, catalog)
 
 
-def _fetch_catalog(dataset_name, cache_dir, cache_subdir):
-    """Fetch catalog for the requested dataset.
+def _fetch_catalog(
+        dataset_name, cache_subdir='datasets', cache_dir=None):
+    """Download catalog for the requested dataset.
 
     Args:
-        dataset_name: The name of the dataset to load.
-        cache_dir: The cache directory for PsiZ.
-        cache_subdir: The subdirectory where downloaded datasets are
-            cached.
+        dataset_name: The name of the hosted dataset.
+        cache_dir (optional): The cache directory for PsiZ.
+        cache_subdir (optional): The subdirectory where downloaded
+            datasets are cached.
 
     Returns:
         catalog: A Catalog object.
@@ -98,6 +109,15 @@ def _fetch_catalog(dataset_name, cache_dir, cache_subdir):
     """
     fname = "catalog_v0.6.0.hdf5"
 
+    # Load from download cache.
+    if cache_dir is None:
+        cache_dir = Path.home() / Path('.psiz')
+    else:
+        cache_dir = Path(cache_dir)
+    dataset_path = cache_dir / Path(cache_subdir, dataset_name)
+    if not dataset_path.exists():
+        dataset_path.mkdir(parents=True)
+
     dataset_exists = True
     if dataset_name == "birds-12":
         origin = "https://osf.io/zs4gh/download"
@@ -131,21 +151,31 @@ def _fetch_catalog(dataset_name, cache_dir, cache_subdir):
     return catalog
 
 
-def _fetch_obs(dataset_name, cache_dir, cache_subdir):
-    """Fetch observations for the requested dataset.
+def _fetch_obs(
+        dataset_name, cache_subdir='datasets', cache_dir=None):
+    """Download observations for the requested dataset.
 
     Args:
-        dataset_name: The name of the dataset to load.
-        cache_dir: The cache directory for PsiZ.
-        cache_subdir: The subdirectory where downloaded datasets are
-            cached.
+        dataset_name: The name of the hosted dataset.
+        cache_dir (optional): The cache directory for PsiZ.
+        cache_subdir (optional): The subdirectory where downloaded
+            datasets are cached.
 
     Returns:
-        obs: An RankObservations object.
+        obs: An Observations object.
 
     """
     fname = 'obs_v0.6.0.hdf5'
 
+    # Load from download cache.
+    if cache_dir is None:
+        cache_dir = Path.home() / Path('.psiz')
+    else:
+        cache_dir = Path(cache_dir)
+    dataset_path = cache_dir / Path(cache_subdir, dataset_name)
+    if not dataset_path.exists():
+        dataset_path.mkdir(parents=True)
+
     dataset_exists = True
     if dataset_name == "birds-12":
         origin = "https://osf.io/jscqn/download"
