@@ -21,8 +21,8 @@ Modules:
     initializers
     layers
     losses
-    metrics
     regularizers
+
 """
 
 import psiz.keras.callbacks
@@ -31,6 +31,9 @@ import psiz.keras.initializers
 import psiz.keras.layers
 import psiz.keras.models
 import psiz.keras.regularizers
-from psiz.keras.restarter import Restarter
 
-__all__ = ['Restarter']
+# Promote `StochasticModel` to `psiz.keras` namespace for convenience and to
+# mirror TensorFlow organization.
+from psiz.keras.models.stochastic_model import StochasticModel
+
+__all__ = ['StochasticModel']
