@@ -24,6 +24,11 @@ from psiz.keras.constraints.min_max import MinMax
 from psiz.keras.constraints.non_neg_norm import NonNegNorm
 
 __all__ = [
-    'Center', 'GreaterEqualThan', 'GreaterThan', 'LessEqualThan', 'LessThan',
-    'MinMax', 'NonNegNorm'
+    'Center',
+    'GreaterEqualThan',
+    'GreaterThan',
+    'LessEqualThan',
+    'LessThan',
+    'MinMax',
+    'NonNegNorm'
 ]
