@@ -20,17 +20,18 @@ Classes:
 
 """
 
+from warnings import warn
+
 import tensorflow as tf
 from tensorflow.python.keras import backend as K
 
 import psiz.keras.constraints as pk_constraints
-from psiz.keras.layers.behaviors.base import Behavior
 
 
 @tf.keras.utils.register_keras_serializable(
     package='psiz.keras.layers', name='RateBehavior'
 )
-class RateBehavior(Behavior):
+class RateBehavior(tf.keras.layers.Layer):
     """A rate behavior layer.
 
     Similarities are converted to probabilities using a parameterized
@@ -46,6 +47,18 @@ class RateBehavior(Behavior):
     `rate`: The growth rate of the logistic function.
 
     """
+    def __init_subclass__(cls, **kwargs):
+        """Subclassing initialization."""
+        warn(
+            (
+                f'{cls.__name__} is deprecated and will be removed. '
+                'Use `psiz.keras.layers.RateSimilarity` instead; '
+                'version_announced=0.8.0; version_scheduled=0.9.0'
+            ),
+            DeprecationWarning,
+            stacklevel=2
+        )
+        super().__init_subclass__(**kwargs)
 
     def __init__(
             self, lower_initializer=None, upper_initializer=None,
@@ -70,6 +83,16 @@ class RateBehavior(Behavior):
             kwargs (optional): Additional keyword arguments.
 
         """
+        warn(
+            (
+                f'{self.__class__.__name__} is deprecated and will be '
+                'removed. '
+                'Use `psiz.keras.layers.RateSimilarity` instead; '
+                'version_announced=0.8.0; version_scheduled=0.9.0'
+            ),
+            DeprecationWarning,
+            stacklevel=2
+        )
         super().__init__(**kwargs)
 
         self.lower_trainable = lower_trainable
