@@ -25,10 +25,8 @@ from tensorflow.python.keras import backend as K
 from tensorflow.python.eager import context
 from tensorflow.python.framework import ops
 from tensorflow.python.ops import embedding_ops
-from tensorflow.python.ops import math_ops
 import tensorflow_probability as tfp
 
-import psiz.tfp.distributions
 import psiz.keras.constraints
 from psiz.keras.layers.embeddings.stochastic_embedding import (
     StochasticEmbedding
@@ -163,7 +161,7 @@ class EmbeddingGammaDiag(StochasticEmbedding):
             constraint=self.rate_constraint
         )
 
-        dist = psiz.tfp.distributions.Gamma(self.concentration, self.rate)
+        dist = tfp.distributions.Gamma(self.concentration, self.rate)
         batch_ndims = tf.size(dist.batch_shape_tensor())
         return tfp.distributions.Independent(
             dist, reinterpreted_batch_ndims=batch_ndims
@@ -171,9 +169,7 @@ class EmbeddingGammaDiag(StochasticEmbedding):
 
     def call(self, inputs):
         """Call."""
-        dtype = K.dtype(inputs)
-        if dtype != 'int32' and dtype != 'int64':
-            inputs = math_ops.cast(inputs, 'int32')
+        inputs = super().call(inputs)
 
         # Delay reification until end of subclass call in order to
         # generate independent samples for each instance in batch_size.
@@ -186,7 +182,7 @@ class EmbeddingGammaDiag(StochasticEmbedding):
 
         # [inputs_concetration, inputs_rate] = super().call(inputs)
         # Use reparameterization trick.
-        dist_batch = psiz.tfp.distributions.Gamma(
+        dist_batch = tfp.distributions.Gamma(
             inputs_concentration, inputs_rate
         )
         # Reify output using samples.
