@@ -22,6 +22,7 @@ Classes:
 
 import tensorflow as tf
 from tensorflow.python.keras import backend as K
+from tensorflow.python.ops import math_ops
 
 
 class StochasticEmbedding(tf.keras.layers.Layer):
@@ -63,6 +64,13 @@ class StochasticEmbedding(tf.keras.layers.Layer):
         self._supports_ragged_inputs = True
         self.sample_shape = sample_shape
 
+    def call(self, inputs):
+        """Call."""
+        dtype = K.dtype(inputs)
+        if dtype != 'int32' and dtype != 'int64':
+            inputs = math_ops.cast(inputs, 'int32')
+        return inputs
+
     def get_config(self):
         """Return layer configuration."""
         config = super().get_config()
