@@ -13,11 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Model initialization file."""
+"""Keras models initialization file."""
 
 from psiz.keras.models.psych_embedding import PsychologicalEmbedding
 from psiz.keras.models.rank import Rank
 from psiz.keras.models.rate import Rate
-from psiz.keras.models.sort import Sort
+from psiz.keras.models.stochastic_model import StochasticModel
 
-__all__ = ['PsychologicalEmbedding', 'Rank', 'Rate', 'Sort']
+__all__ = [
+    'PsychologicalEmbedding',
+    'Rank',
+    'Rate',
+    'StochasticModel'
+]
