@@ -46,6 +46,19 @@ class PsychologicalEmbedding(tf.keras.Model):
             layers.
 
     """
+    def __init_subclass__(cls, **kwargs):
+        """Subclassing initialization."""
+        warnings.warn(
+            (
+                f'{cls.__name__} is deprecated and will be removed. '
+                'You should create a subclassed or functional Model instead. '
+                'Please see the models in the updated `examples/`; '
+                'version_announced=0.8.0; version_scheduled=0.9.0'
+            ),
+            DeprecationWarning,
+            stacklevel=2
+        )
+        super().__init_subclass__(**kwargs)
 
     def __init__(
             self, stimuli=None, kernel=None, behavior=None, n_sample=1,
@@ -74,6 +87,17 @@ class PsychologicalEmbedding(tf.keras.Model):
             ValueError: If arguments are invalid.
 
         """
+        warnings.warn(
+            (
+                f'{self.__class__.__name__} is deprecated and will be '
+                'removed. '
+                'You should create a subclassed or functional Model instead. '
+                'Please see the models in the updated `examples/`; '
+                'version_announced=0.8.0; version_scheduled=0.9.0'
+            ),
+            DeprecationWarning,
+            stacklevel=2
+        )
         super().__init__(**kwargs)
 
         # Assign layers.
@@ -88,7 +112,6 @@ class PsychologicalEmbedding(tf.keras.Model):
             'behavior': use_group_behavior
         }
 
-        self._kl_weight = 0.
         self._n_sample = n_sample
 
     @property
@@ -103,7 +126,7 @@ class PsychologicalEmbedding(tf.keras.Model):
                 if self.stimuli.mask_zero:
                     n_stimuli -= 1
             except AttributeError:
-                # Assume Gate or GateMulti layer.
+                # Assume BraidGate layer.
                 n_stimuli = self.stimuli.subnets[0].input_dim
                 if self.stimuli.subnets[0].mask_zero:
                     n_stimuli -= 1
@@ -117,7 +140,7 @@ class PsychologicalEmbedding(tf.keras.Model):
             # Assume embedding layer.
             output_dim = self.stimuli.output_dim
         except AttributeError:
-            # Assume Gate or GateMulti layer.
+            # Assume SubhetGate layer.
             output_dim = self.stimuli.subnets[0].output_dim
 
         return output_dim
