@@ -22,6 +22,9 @@ from psiz.mplot.embedding_input_dimension import embedding_input_dimension
 from psiz.mplot.embedding_output_dimension import embedding_output_dimension
 
 __all__ = [
-    'bvn_ellipse', 'hdi_bvn', 'heatmap_embeddings',
-    'embedding_input_dimension', 'embedding_output_dimension'
+    'bvn_ellipse',
+    'hdi_bvn',
+    'heatmap_embeddings',
+    'embedding_input_dimension',
+    'embedding_output_dimension'
 ]
