@@ -26,7 +26,6 @@ from psiz.trials.similarity.rank.rank_docket import RankDocket
 from psiz.trials.similarity.rank.rank_observations import RankObservations
 from psiz.trials.similarity.rate.rate_docket import RateDocket
 from psiz.trials.similarity.rate.rate_observations import RateObservations
-from psiz.trials.experimental.trial_dataset import TrialDataset
 
 
 def load_trials(filepath):
@@ -70,7 +69,6 @@ def load_trials(filepath):
         'RankObservations': RankObservations,
         'RateDocket': RateDocket,
         'RateObservations': RateObservations,
-        'TrialDataset': TrialDataset,
     }
     if class_name in custom_objects:
         trial_class = custom_objects[class_name]
