@@ -230,7 +230,7 @@ class RankObservations(RankTrials):
 
     def _check_weight(self, weight):
         """Check the argument weight."""
-        weight = weight.astype(np.float)
+        weight = weight.astype(float)
         # Check shape agreement.
         if not (weight.shape[0] == self.n_trial):
             raise ValueError((
@@ -240,7 +240,7 @@ class RankObservations(RankTrials):
 
     def _check_rt(self, rt_ms):
         """Check the argument rt_ms."""
-        rt_ms = rt_ms.astype(np.float)
+        rt_ms = rt_ms.astype(float)
         # Check shape agreement.
         if not (rt_ms.shape[0] == self.n_trial):
             raise ValueError((
@@ -386,7 +386,7 @@ class RankObservations(RankTrials):
         f.close()
 
     def as_dataset(self):
-        """Format necessary data as Tensorflow.data.Dataset object.
+        """Format necessary data as tensorflow.data.Dataset object.
 
         Returns:
             ds_obs: The data necessary for inference, formatted as a
@@ -398,8 +398,6 @@ class RankObservations(RankTrials):
         # singleton dimensions on the call signautre for inputs that only
         # have one dimension. Add the singleton dimensions here solves the
         # problem.
-        # NOTE: We use stimulus_set + 1, since TensorFlow requires "0", not
-        # "-1" to indicate a masked value.
         # NOTE: The dimensions of inputs are expanded to have an additional
         # singleton third dimension to indicate that there is only one outcome
         # that we are interested for each trial.
