@@ -195,7 +195,7 @@ class RateObservations(RateTrials):
 
     def _check_weight(self, weight):
         """Check the argument weight."""
-        weight = weight.astype(np.float)
+        weight = weight.astype(float)
         # Check shape agreement.
         if not (weight.shape[0] == self.n_trial):
             raise ValueError((
@@ -205,7 +205,7 @@ class RateObservations(RateTrials):
 
     def _check_rt(self, rt_ms):
         """Check the argument rt_ms."""
-        rt_ms = rt_ms.astype(np.float)
+        rt_ms = rt_ms.astype(float)
         # Check shape agreement.
         if not (rt_ms.shape[0] == self.n_trial):
             raise ValueError((
@@ -320,7 +320,7 @@ class RateObservations(RateTrials):
         f.close()
 
     def as_dataset(self):
-        """Format necessary data as Tensorflow.data.Dataset object.
+        """Format necessary data as tensorflow.data.Dataset object.
 
         Returns:
             ds_obs: The data necessary for inference, formatted as a
@@ -332,8 +332,6 @@ class RateObservations(RateTrials):
         # singleton dimensions on the call signautre for inputs that only
         # have one dimension. Add the singleton dimensions here solves the
         # problem.
-        # NOTE: We use stimulus_set + 1, since TensorFlow requires "0", not
-        # "-1" to indicate a masked value.
         # NOTE: The dimensions of inputs are expanded to have an additional
         # singleton third dimension to indicate that there is only one outcome
         # that we are interested for each trial.
@@ -433,19 +431,19 @@ class RateObservations(RateTrials):
         if "weight" in f:
             weight = f["weight"][()]
         else:
-            weight = np.ones((stimulus_set.shape[0]))
+            weight = np.ones((stimulus_set.shape[0]))  # pylint: disable=no-member
         if "rt_ms" in f:
             rt_ms = f["rt_ms"][()]
         else:
-            rt_ms = -np.ones((stimulus_set.shape[0]))
+            rt_ms = -np.ones((stimulus_set.shape[0]))  # pylint: disable=no-member
         if "agent_id" in f:
             agent_id = f["agent_id"][()]
         else:
-            agent_id = np.zeros((stimulus_set.shape[0]))
+            agent_id = np.zeros((stimulus_set.shape[0]))  # pylint: disable=no-member
         if "session_id" in f:
             session_id = f["session_id"][()]
         else:
-            session_id = np.zeros((stimulus_set.shape[0]))
+            session_id = np.zeros((stimulus_set.shape[0]))  # pylint: disable=no-member
         f.close()
 
         trials = RateObservations(
