@@ -71,6 +71,19 @@ class SimilarityTrials(metaclass=ABCMeta):
     """
     _mask_value = 0
 
+    def __init_subclass__(cls, **kwargs):
+        """Subclassing initialization."""
+        warnings.warn(
+            (
+                f'{cls.__name__} is deprecated and will be removed; '
+                'Please use the `psiz.data` module for creating datasets; '
+                'version_announced=0.8.0; version_scheduled=0.9.0'
+            ),
+            DeprecationWarning,
+            stacklevel=2
+        )
+        super().__init_subclass__(**kwargs)
+
     def __init__(self, stimulus_set, mask_zero=False):
         """Initialize.
 
@@ -86,6 +99,16 @@ class SimilarityTrials(metaclass=ABCMeta):
                 value.
 
         """
+        warnings.warn(
+            (
+                f'{self.__class__.__name__} is deprecated and will be '
+                'removed. '
+                'Please use the `psiz.data` module for creating datasets; '
+                'version_announced=0.8.0; version_scheduled=0.9.0'
+            ),
+            DeprecationWarning,
+            stacklevel=2
+        )
         self.mask_zero = mask_zero
 
         stimulus_set = self._check_stimulus_set(stimulus_set)
@@ -241,8 +264,8 @@ class SimilarityTrials(metaclass=ABCMeta):
             if 'groups' in index:
                 # Must handle groups separately.
                 parts = index.split('_')
-                group_col = int(parts[-1])
-                bidx_key = np.equal(self.groups[:, group_col], value)
+                groups_subset = int(parts[-1])
+                bidx_key = np.equal(self.groups[:, groups_subset], value)
             else:
                 bidx_key = np.equal(getattr(self, index), value)
             # Determine intersection.
